## 3.0.2 (2022-02-20)

flask-cors: remove unused allowlist (#7309)

Co-authored-by: hauntsaninja <>

## 3.0.1 (2022-01-22)

Use class-based syntax for `TypedDict` in `Flask-Cors/flask_cors/core.pyi` (#6995)

Refs https://github.com/PyCQA/flake8-pyi/pull/133

Add missing default values to flask-cors cross_origin (#6994)

## 3.0.0 (2022-01-22)

Add stubs for flask-cors (#6939)

